pub struct Config {
pub base_url: Url,
pub client: Client,
pub limiter: RateLimiter<NotKeyed, InMemoryState, MonotonicClock>,
pub bearer_token: String,
pub user_agent: Option<String>,
}Expand description
The client configuration
Fields
base_url: UrlThe base URL of the API
client: ClientThe reqwest client that is used for every request
limiter: RateLimiter<NotKeyed, InMemoryState, MonotonicClock>The rate limiter to use for the client
bearer_token: StringThe bearer token for readonly access to the API
user_agent: Option<String>An optional user agent string to provide to the API
Implementations